pkg

package
v0.0.0-...-b683721 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2020 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Info

func Info(s string)

Info prints text in blue

func Infof

func Infof(f string, s ...interface{})

Infof prints text in blue with formatting

func StrToIntSlice

func StrToIntSlice(s []string) []int

StrToIntSlice provides converting of string slice to int slice

func Text

func Text(s string) string

Text returns formatted string

func Update

func Update(path string, releases []*NewRelease) error

Update provides updating of deps. It might be updated specific dep or all deps

func Warningf

func Warningf(f string, s ...interface{})

Warningf rprint text in red

Types

type Dependency

type Dependency struct {
	Path   string
	Tag    string
	Author string
	Name   string
}

Dependency defines single dependency in format name-tag

func Parse

func Parse(path string) ([]Dependency, error)

Parse provides parsing of go.mod file

type NewRelease

type NewRelease struct {
	Name        string
	Tag         string
	CurrentTag  string
	PublishedAt string
	Body        string
	URL         string
}

NewRelease defines struct for showing new releases

func NewReleases

func NewReleases(token string, deps []Dependency) ([]*NewRelease, error)

NewReleases retruns list of all new releases

Directories

Path Synopsis

Jump to